Macro smolprng::prng_iter [−][src]
macro_rules! prng_iter {
($algo_struct_name : ty) => { ... };
}Expand description
A macro that will add the implmentation of Iterator for a given PRNG
macro_rules! prng_iter {
($algo_struct_name : ty) => { ... };
}A macro that will add the implmentation of Iterator for a given PRNG