Trait smolprng::smol_core::Algorithm[][src]

pub trait Algorithm {
    type Output: AlgorithmOutput;
    fn gen(&mut self) -> Self::Output;
}
This is the central algorithm trait that is implemented bt the generators of the package

Associated Types

The ouput type of the Algorithm such as u32, ect.

Required methods

Central generation function of the Algorithm trait, this take in a state struct and returns the ouput of the algorithm

Implementors