Trait smolprng::smol_core::AlgorithmOutput[][src]

pub trait AlgorithmOutput: Shr<u8, Output = Self> + Shl<u8, Output = Self> + BitOrAssign<Self> + Sized + BitAnd<Self> {
    const SIZE: usize;

    fn cast_to_u8(self) -> u8;
fn cast_to_u16(self) -> u16;
fn cast_to_u32(self) -> u32;
fn cast_to_u64(self) -> u64;
fn cast_to_u128(self) -> u128;
fn get_low(self) -> bool; }
This is the helper trait that that all Algorithms must output a type of u8,u16,u32,u64,u128,

Associated Constants

The size in bytes of the algorithm output

Required methods

Helper function that converts to u8

Helper function that converts to u16

Helper function that converts to u32

Helper function that converts to u64

Helper function that converts to u128

Helper function returns that returns the lowest bit of an algorithm output as a bool

Implementations on Foreign Types

Implementors