Trait smolprng::smol_core::Algorithm [−][src]
pub trait Algorithm {
type Output: AlgorithmOutput;
fn gen(&mut self) -> Self::Output;
}Expand description
This is the central algorithm trait that is implemented bt the generators of the package
Associated Types
type Output: AlgorithmOutput
type Output: AlgorithmOutput
The ouput type of the Algorithm such as u32, ect.